==> kubernetes-model-1.0.62-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerPortBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class ContainerPortBuilder extends ContainerPortFluentImpl<ContainerPortBuilder> implements VisitableBuilder<ContainerPort,ContainerPortBuilder>{

    ContainerPortFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerPortBuilder(){
            this(true);
    }
    public ContainerPortBuilder(Boolean validationEnabled){
            this(new ContainerPort(), validationEnabled);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerPort(), validationEnabled);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent,ContainerPort instance){
            this(fluent, instance, true);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent,ContainerPort instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withContainerPort(instance.getContainerPort()); 
            fluent.withHostIP(instance.getHostIP()); 
            fluent.withHostPort(instance.getHostPort()); 
            fluent.withName(instance.getName()); 
            fluent.withProtocol(instance.getProtocol()); 
            this.validationEnabled = validationEnabled; 
    }
    public ContainerPortBuilder(ContainerPort instance){
            this(instance,true);
    }
    public ContainerPortBuilder(ContainerPort instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withContainerPort(instance.getContainerPort()); 
            this.withHostIP(instance.getHostIP()); 
            this.withHostPort(instance.getHostPort()); 
            this.withName(instance.getName()); 
            this.withProtocol(instance.getProtocol()); 
            this.validationEnabled = validationEnabled; 
    }

    public ContainerPort build(){
            ContainerPort buildable = new ContainerPort(fluent.getContainerPort(),fluent.getHostIP(),fluent.getHostPort(),fluent.getName(),fluent.getProtocol());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerPortBuilder that = (ContainerPortBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerPortBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ContainerPortBuilder extends ContainerPortFluentImpl<ContainerPortBuilder> implements VisitableBuilder<ContainerPort,ContainerPortBuilder>{

    ContainerPortFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerPortBuilder(){
            this(true);
    }
    public ContainerPortBuilder(Boolean validationEnabled){
            this(new ContainerPort(), validationEnabled);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerPort(), validationEnabled);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent,ContainerPort instance){
            this(fluent, instance, true);
    }
    public ContainerPortBuilder(ContainerPortFluent<?> fluent,ContainerPort instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withContainerPort(instance.getContainerPort()); 
            fluent.withHostIP(instance.getHostIP()); 
            fluent.withHostPort(instance.getHostPort()); 
            fluent.withName(instance.getName()); 
            fluent.withProtocol(instance.getProtocol()); 
            this.validationEnabled = validationEnabled; 
    }
    public ContainerPortBuilder(ContainerPort instance){
            this(instance,true);
    }
    public ContainerPortBuilder(ContainerPort instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withContainerPort(instance.getContainerPort()); 
            this.withHostIP(instance.getHostIP()); 
            this.withHostPort(instance.getHostPort()); 
            this.withName(instance.getName()); 
            this.withProtocol(instance.getProtocol()); 
            this.validationEnabled = validationEnabled; 
    }

    public ContainerPort build(){
            ContainerPort buildable = new ContainerPort(fluent.getContainerPort(),fluent.getHostIP(),fluent.getHostPort(),fluent.getName(),fluent.getProtocol());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerPortBuilder that = (ContainerPortBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
